{% extends "!layout.html" %}
{% set script_files = script_files + [pathto("_static/collapse.js", True)] %}
{% block extrahead %}
    <link href="{{ pathto("_static/style.css", True) }}" rel="stylesheet" type="text/css">
{% endblock %}
